# coding: utf-8

# flake8: noqa
"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from cfbd.models.advanced_game_stat import AdvancedGameStat
from cfbd.models.advanced_game_stat_offense import AdvancedGameStatOffense
from cfbd.models.advanced_game_stat_offense_rushing_plays import AdvancedGameStatOffenseRushingPlays
from cfbd.models.advanced_game_stat_offense_standard_downs import AdvancedGameStatOffenseStandardDowns
from cfbd.models.advanced_season_stat import AdvancedSeasonStat
from cfbd.models.advanced_season_stat_defense import AdvancedSeasonStatDefense
from cfbd.models.advanced_season_stat_offense import AdvancedSeasonStatOffense
from cfbd.models.advanced_season_stat_offense_field_position import AdvancedSeasonStatOffenseFieldPosition
from cfbd.models.advanced_season_stat_offense_rushing_plays import AdvancedSeasonStatOffenseRushingPlays
from cfbd.models.advanced_season_stat_offense_standard_downs import AdvancedSeasonStatOffenseStandardDowns
from cfbd.models.box_score import BoxScore
from cfbd.models.box_score_players import BoxScorePlayers
from cfbd.models.box_score_players_average import BoxScorePlayersAverage
from cfbd.models.box_score_players_ppa import BoxScorePlayersPpa
from cfbd.models.box_score_players_usage import BoxScorePlayersUsage
from cfbd.models.box_score_teams import BoxScoreTeams
from cfbd.models.box_score_teams_explosiveness import BoxScoreTeamsExplosiveness
from cfbd.models.box_score_teams_field_position import BoxScoreTeamsFieldPosition
from cfbd.models.box_score_teams_havoc import BoxScoreTeamsHavoc
from cfbd.models.box_score_teams_overall import BoxScoreTeamsOverall
from cfbd.models.box_score_teams_ppa import BoxScoreTeamsPpa
from cfbd.models.box_score_teams_rushing import BoxScoreTeamsRushing
from cfbd.models.box_score_teams_scoring_opportunities import BoxScoreTeamsScoringOpportunities
from cfbd.models.box_score_teams_success_rates import BoxScoreTeamsSuccessRates
from cfbd.models.conference import Conference
from cfbd.models.conference_sp_rating import ConferenceSPRating
from cfbd.models.drive import Drive
from cfbd.models.drive_start_time import DriveStartTime
from cfbd.models.game import Game
from cfbd.models.game_lines import GameLines
from cfbd.models.game_lines_lines import GameLinesLines
from cfbd.models.game_media import GameMedia
from cfbd.models.game_ppa import GamePPA
from cfbd.models.game_ppa_offense import GamePPAOffense
from cfbd.models.inline_response200 import InlineResponse200
from cfbd.models.play import Play
from cfbd.models.play_stat import PlayStat
from cfbd.models.play_stat_type import PlayStatType
from cfbd.models.play_type import PlayType
from cfbd.models.play_wp import PlayWP
from cfbd.models.player import Player
from cfbd.models.player_game import PlayerGame
from cfbd.models.player_game_athletes import PlayerGameAthletes
from cfbd.models.player_game_categories import PlayerGameCategories
from cfbd.models.player_game_ppa import PlayerGamePPA
from cfbd.models.player_game_ppa_average_ppa import PlayerGamePPAAveragePPA
from cfbd.models.player_game_school import PlayerGameSchool
from cfbd.models.player_game_teams import PlayerGameTeams
from cfbd.models.player_game_types import PlayerGameTypes
from cfbd.models.player_search_result import PlayerSearchResult
from cfbd.models.player_season_ppa import PlayerSeasonPPA
from cfbd.models.player_season_ppa_average_ppa import PlayerSeasonPPAAveragePPA
from cfbd.models.player_season_stat import PlayerSeasonStat
from cfbd.models.player_usage import PlayerUsage
from cfbd.models.player_usage_usage import PlayerUsageUsage
from cfbd.models.position_group_recruiting_rating import PositionGroupRecruitingRating
from cfbd.models.predicted_points import PredictedPoints
from cfbd.models.pregame_wp import PregameWP
from cfbd.models.ranking_week import RankingWeek
from cfbd.models.ranking_week_polls import RankingWeekPolls
from cfbd.models.ranking_week_ranks import RankingWeekRanks
from cfbd.models.recruit import Recruit
from cfbd.models.returning_production import ReturningProduction
from cfbd.models.team import Team
from cfbd.models.team_game import TeamGame
from cfbd.models.team_game_stats import TeamGameStats
from cfbd.models.team_game_teams import TeamGameTeams
from cfbd.models.team_matchup import TeamMatchup
from cfbd.models.team_matchup_games import TeamMatchupGames
from cfbd.models.team_ppa import TeamPPA
from cfbd.models.team_ppa_offense import TeamPPAOffense
from cfbd.models.team_ppa_offense_cumulative import TeamPPAOffenseCumulative
from cfbd.models.team_record import TeamRecord
from cfbd.models.team_record_total import TeamRecordTotal
from cfbd.models.team_recruiting_rank import TeamRecruitingRank
from cfbd.models.team_sp_rating import TeamSPRating
from cfbd.models.team_sp_rating_defense import TeamSPRatingDefense
from cfbd.models.team_sp_rating_defense_havoc import TeamSPRatingDefenseHavoc
from cfbd.models.team_sp_rating_offense import TeamSPRatingOffense
from cfbd.models.team_sp_rating_special_teams import TeamSPRatingSpecialTeams
from cfbd.models.team_srs_rating import TeamSRSRating
from cfbd.models.team_season import TeamSeason
from cfbd.models.team_season_stat import TeamSeasonStat
from cfbd.models.team_talent import TeamTalent
from cfbd.models.venue import Venue
from cfbd.models.venue_location import VenueLocation



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cfbd
from cfbd.api.teams_api import TeamsApi  # noqa: E501
from cfbd.rest import ApiException


class TestTeamsApi(unittest.TestCase):
    """TeamsApi unit test stubs"""

    def setUp(self):
        self.api = cfbd.api.teams_api.TeamsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_fbs_teams(self):
        """Test case for get_fbs_teams

        FBS team list  # noqa: E501
        """
        pass

    def test_get_roster(self):
        """Test case for get_roster

        Team rosters  # noqa: E501
        """
        pass

    def test_get_talent(self):
        """Test case for get_talent

        Team talent composite rankings  # noqa: E501
        """
        pass

    def test_get_team_matchup(self):
        """Test case for get_team_matchup

        Team matchup history  # noqa: E501
        """
        pass

    def test_get_teams(self):
        """Test case for get_teams

        Team information  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Game(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'season': 'int',
        'week': 'int',
        'season_type': 'str',
        'start_date': 'str',
        'start_time_tbd': 'bool',
        'neutral_site': 'bool',
        'conference_game': 'bool',
        'attendance': 'int',
        'venue_id': 'int',
        'venue': 'str',
        'home_id': 'int',
        'home_team': 'str',
        'home_conference': 'str',
        'home_points': 'int',
        'home_line_scores': 'list[int]',
        'home_post_win_prob': 'float',
        'away_id': 'int',
        'away_team': 'str',
        'away_conference': 'str',
        'away_points': 'int',
        'away_line_scores': 'list[int]',
        'away_post_win_prob': 'float',
        'excitement_index': 'float'
    }

    attribute_map = {
        'id': 'id',
        'season': 'season',
        'week': 'week',
        'season_type': 'season_type',
        'start_date': 'start_date',
        'start_time_tbd': 'start_time_tbd',
        'neutral_site': 'neutral_site',
        'conference_game': 'conference_game',
        'attendance': 'attendance',
        'venue_id': 'venue_id',
        'venue': 'venue',
        'home_id': 'home_id',
        'home_team': 'home_team',
        'home_conference': 'home_conference',
        'home_points': 'home_points',
        'home_line_scores': 'home_line_scores',
        'home_post_win_prob': 'home_post_win_prob',
        'away_id': 'away_id',
        'away_team': 'away_team',
        'away_conference': 'away_conference',
        'away_points': 'away_points',
        'away_line_scores': 'away_line_scores',
        'away_post_win_prob': 'away_post_win_prob',
        'excitement_index': 'excitement_index'
    }

    def __init__(self, id=None, season=None, week=None, season_type=None, start_date=None, start_time_tbd=None, neutral_site=None, conference_game=None, attendance=None, venue_id=None, venue=None, home_id=None, home_team=None, home_conference=None, home_points=None, home_line_scores=None, home_post_win_prob=None, away_id=None, away_team=None, away_conference=None, away_points=None, away_line_scores=None, away_post_win_prob=None, excitement_index=None):  # noqa: E501
        """Game - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._season = None
        self._week = None
        self._season_type = None
        self._start_date = None
        self._start_time_tbd = None
        self._neutral_site = None
        self._conference_game = None
        self._attendance = None
        self._venue_id = None
        self._venue = None
        self._home_id = None
        self._home_team = None
        self._home_conference = None
        self._home_points = None
        self._home_line_scores = None
        self._home_post_win_prob = None
        self._away_id = None
        self._away_team = None
        self._away_conference = None
        self._away_points = None
        self._away_line_scores = None
        self._away_post_win_prob = None
        self._excitement_index = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if season is not None:
            self.season = season
        if week is not None:
            self.week = week
        if season_type is not None:
            self.season_type = season_type
        if start_date is not None:
            self.start_date = start_date
        if start_time_tbd is not None:
            self.start_time_tbd = start_time_tbd
        if neutral_site is not None:
            self.neutral_site = neutral_site
        if conference_game is not None:
            self.conference_game = conference_game
        if attendance is not None:
            self.attendance = attendance
        if venue_id is not None:
            self.venue_id = venue_id
        if venue is not None:
            self.venue = venue
        if home_id is not None:
            self.home_id = home_id
        if home_team is not None:
            self.home_team = home_team
        if home_conference is not None:
            self.home_conference = home_conference
        if home_points is not None:
            self.home_points = home_points
        if home_line_scores is not None:
            self.home_line_scores = home_line_scores
        if home_post_win_prob is not None:
            self.home_post_win_prob = home_post_win_prob
        if away_id is not None:
            self.away_id = away_id
        if away_team is not None:
            self.away_team = away_team
        if away_conference is not None:
            self.away_conference = away_conference
        if away_points is not None:
            self.away_points = away_points
        if away_line_scores is not None:
            self.away_line_scores = away_line_scores
        if away_post_win_prob is not None:
            self.away_post_win_prob = away_post_win_prob
        if excitement_index is not None:
            self.excitement_index = excitement_index

    @property
    def id(self):
        """Gets the id of this Game.  # noqa: E501


        :return: The id of this Game.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Game.


        :param id: The id of this Game.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def season(self):
        """Gets the season of this Game.  # noqa: E501


        :return: The season of this Game.  # noqa: E501
        :rtype: int
        """
        return self._season

    @season.setter
    def season(self, season):
        """Sets the season of this Game.


        :param season: The season of this Game.  # noqa: E501
        :type: int
        """

        self._season = season

    @property
    def week(self):
        """Gets the week of this Game.  # noqa: E501


        :return: The week of this Game.  # noqa: E501
        :rtype: int
        """
        return self._week

    @week.setter
    def week(self, week):
        """Sets the week of this Game.


        :param week: The week of this Game.  # noqa: E501
        :type: int
        """

        self._week = week

    @property
    def season_type(self):
        """Gets the season_type of this Game.  # noqa: E501


        :return: The season_type of this Game.  # noqa: E501
        :rtype: str
        """
        return self._season_type

    @season_type.setter
    def season_type(self, season_type):
        """Sets the season_type of this Game.


        :param season_type: The season_type of this Game.  # noqa: E501
        :type: str
        """

        self._season_type = season_type

    @property
    def start_date(self):
        """Gets the start_date of this Game.  # noqa: E501


        :return: The start_date of this Game.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Game.


        :param start_date: The start_date of this Game.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def start_time_tbd(self):
        """Gets the start_time_tbd of this Game.  # noqa: E501


        :return: The start_time_tbd of this Game.  # noqa: E501
        :rtype: bool
        """
        return self._start_time_tbd

    @start_time_tbd.setter
    def start_time_tbd(self, start_time_tbd):
        """Sets the start_time_tbd of this Game.


        :param start_time_tbd: The start_time_tbd of this Game.  # noqa: E501
        :type: bool
        """

        self._start_time_tbd = start_time_tbd

    @property
    def neutral_site(self):
        """Gets the neutral_site of this Game.  # noqa: E501


        :return: The neutral_site of this Game.  # noqa: E501
        :rtype: bool
        """
        return self._neutral_site

    @neutral_site.setter
    def neutral_site(self, neutral_site):
        """Sets the neutral_site of this Game.


        :param neutral_site: The neutral_site of this Game.  # noqa: E501
        :type: bool
        """

        self._neutral_site = neutral_site

    @property
    def conference_game(self):
        """Gets the conference_game of this Game.  # noqa: E501


        :return: The conference_game of this Game.  # noqa: E501
        :rtype: bool
        """
        return self._conference_game

    @conference_game.setter
    def conference_game(self, conference_game):
        """Sets the conference_game of this Game.


        :param conference_game: The conference_game of this Game.  # noqa: E501
        :type: bool
        """

        self._conference_game = conference_game

    @property
    def attendance(self):
        """Gets the attendance of this Game.  # noqa: E501


        :return: The attendance of this Game.  # noqa: E501
        :rtype: int
        """
        return self._attendance

    @attendance.setter
    def attendance(self, attendance):
        """Sets the attendance of this Game.


        :param attendance: The attendance of this Game.  # noqa: E501
        :type: int
        """

        self._attendance = attendance

    @property
    def venue_id(self):
        """Gets the venue_id of this Game.  # noqa: E501


        :return: The venue_id of this Game.  # noqa: E501
        :rtype: int
        """
        return self._venue_id

    @venue_id.setter
    def venue_id(self, venue_id):
        """Sets the venue_id of this Game.


        :param venue_id: The venue_id of this Game.  # noqa: E501
        :type: int
        """

        self._venue_id = venue_id

    @property
    def venue(self):
        """Gets the venue of this Game.  # noqa: E501


        :return: The venue of this Game.  # noqa: E501
        :rtype: str
        """
        return self._venue

    @venue.setter
    def venue(self, venue):
        """Sets the venue of this Game.


        :param venue: The venue of this Game.  # noqa: E501
        :type: str
        """

        self._venue = venue

    @property
    def home_id(self):
        """Gets the home_id of this Game.  # noqa: E501


        :return: The home_id of this Game.  # noqa: E501
        :rtype: int
        """
        return self._home_id

    @home_id.setter
    def home_id(self, home_id):
        """Sets the home_id of this Game.


        :param home_id: The home_id of this Game.  # noqa: E501
        :type: int
        """

        self._home_id = home_id

    @property
    def home_team(self):
        """Gets the home_team of this Game.  # noqa: E501


        :return: The home_team of this Game.  # noqa: E501
        :rtype: str
        """
        return self._home_team

    @home_team.setter
    def home_team(self, home_team):
        """Sets the home_team of this Game.


        :param home_team: The home_team of this Game.  # noqa: E501
        :type: str
        """

        self._home_team = home_team

    @property
    def home_conference(self):
        """Gets the home_conference of this Game.  # noqa: E501


        :return: The home_conference of this Game.  # noqa: E501
        :rtype: str
        """
        return self._home_conference

    @home_conference.setter
    def home_conference(self, home_conference):
        """Sets the home_conference of this Game.


        :param home_conference: The home_conference of this Game.  # noqa: E501
        :type: str
        """

        self._home_conference = home_conference

    @property
    def home_points(self):
        """Gets the home_points of this Game.  # noqa: E501


        :return: The home_points of this Game.  # noqa: E501
        :rtype: int
        """
        return self._home_points

    @home_points.setter
    def home_points(self, home_points):
        """Sets the home_points of this Game.


        :param home_points: The home_points of this Game.  # noqa: E501
        :type: int
        """

        self._home_points = home_points

    @property
    def home_line_scores(self):
        """Gets the home_line_scores of this Game.  # noqa: E501


        :return: The home_line_scores of this Game.  # noqa: E501
        :rtype: list[int]
        """
        return self._home_line_scores

    @home_line_scores.setter
    def home_line_scores(self, home_line_scores):
        """Sets the home_line_scores of this Game.


        :param home_line_scores: The home_line_scores of this Game.  # noqa: E501
        :type: list[int]
        """

        self._home_line_scores = home_line_scores

    @property
    def home_post_win_prob(self):
        """Gets the home_post_win_prob of this Game.  # noqa: E501


        :return: The home_post_win_prob of this Game.  # noqa: E501
        :rtype: float
        """
        return self._home_post_win_prob

    @home_post_win_prob.setter
    def home_post_win_prob(self, home_post_win_prob):
        """Sets the home_post_win_prob of this Game.


        :param home_post_win_prob: The home_post_win_prob of this Game.  # noqa: E501
        :type: float
        """

        self._home_post_win_prob = home_post_win_prob

    @property
    def away_id(self):
        """Gets the away_id of this Game.  # noqa: E501


        :return: The away_id of this Game.  # noqa: E501
        :rtype: int
        """
        return self._away_id

    @away_id.setter
    def away_id(self, away_id):
        """Sets the away_id of this Game.


        :param away_id: The away_id of this Game.  # noqa: E501
        :type: int
        """

        self._away_id = away_id

    @property
    def away_team(self):
        """Gets the away_team of this Game.  # noqa: E501


        :return: The away_team of this Game.  # noqa: E501
        :rtype: str
        """
        return self._away_team

    @away_team.setter
    def away_team(self, away_team):
        """Sets the away_team of this Game.


        :param away_team: The away_team of this Game.  # noqa: E501
        :type: str
        """

        self._away_team = away_team

    @property
    def away_conference(self):
        """Gets the away_conference of this Game.  # noqa: E501


        :return: The away_conference of this Game.  # noqa: E501
        :rtype: str
        """
        return self._away_conference

    @away_conference.setter
    def away_conference(self, away_conference):
        """Sets the away_conference of this Game.


        :param away_conference: The away_conference of this Game.  # noqa: E501
        :type: str
        """

        self._away_conference = away_conference

    @property
    def away_points(self):
        """Gets the away_points of this Game.  # noqa: E501


        :return: The away_points of this Game.  # noqa: E501
        :rtype: int
        """
        return self._away_points

    @away_points.setter
    def away_points(self, away_points):
        """Sets the away_points of this Game.


        :param away_points: The away_points of this Game.  # noqa: E501
        :type: int
        """

        self._away_points = away_points

    @property
    def away_line_scores(self):
        """Gets the away_line_scores of this Game.  # noqa: E501


        :return: The away_line_scores of this Game.  # noqa: E501
        :rtype: list[int]
        """
        return self._away_line_scores

    @away_line_scores.setter
    def away_line_scores(self, away_line_scores):
        """Sets the away_line_scores of this Game.


        :param away_line_scores: The away_line_scores of this Game.  # noqa: E501
        :type: list[int]
        """

        self._away_line_scores = away_line_scores

    @property
    def away_post_win_prob(self):
        """Gets the away_post_win_prob of this Game.  # noqa: E501


        :return: The away_post_win_prob of this Game.  # noqa: E501
        :rtype: float
        """
        return self._away_post_win_prob

    @away_post_win_prob.setter
    def away_post_win_prob(self, away_post_win_prob):
        """Sets the away_post_win_prob of this Game.


        :param away_post_win_prob: The away_post_win_prob of this Game.  # noqa: E501
        :type: float
        """

        self._away_post_win_prob = away_post_win_prob

    @property
    def excitement_index(self):
        """Gets the excitement_index of this Game.  # noqa: E501


        :return: The excitement_index of this Game.  # noqa: E501
        :rtype: float
        """
        return self._excitement_index

    @excitement_index.setter
    def excitement_index(self, excitement_index):
        """Sets the excitement_index of this Game.


        :param excitement_index: The excitement_index of this Game.  # noqa: E501
        :type: float
        """

        self._excitement_index = excitement_index

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Game, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Game):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Player(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'first_name': 'str',
        'last_name': 'str',
        'height': 'int',
        'weight': 'int',
        'jersey': 'int',
        'year': 'int',
        'position': 'str',
        'city': 'str',
        'state': 'str',
        'country': 'str'
    }

    attribute_map = {
        'id': 'id',
        'first_name': 'first_name',
        'last_name': 'last_name',
        'height': 'height',
        'weight': 'weight',
        'jersey': 'jersey',
        'year': 'year',
        'position': 'position',
        'city': 'city',
        'state': 'state',
        'country': 'country'
    }

    def __init__(self, id=None, first_name=None, last_name=None, height=None, weight=None, jersey=None, year=None, position=None, city=None, state=None, country=None):  # noqa: E501
        """Player - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._first_name = None
        self._last_name = None
        self._height = None
        self._weight = None
        self._jersey = None
        self._year = None
        self._position = None
        self._city = None
        self._state = None
        self._country = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if height is not None:
            self.height = height
        if weight is not None:
            self.weight = weight
        if jersey is not None:
            self.jersey = jersey
        if year is not None:
            self.year = year
        if position is not None:
            self.position = position
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country

    @property
    def id(self):
        """Gets the id of this Player.  # noqa: E501


        :return: The id of this Player.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Player.


        :param id: The id of this Player.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def first_name(self):
        """Gets the first_name of this Player.  # noqa: E501


        :return: The first_name of this Player.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this Player.


        :param first_name: The first_name of this Player.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this Player.  # noqa: E501


        :return: The last_name of this Player.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this Player.


        :param last_name: The last_name of this Player.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def height(self):
        """Gets the height of this Player.  # noqa: E501


        :return: The height of this Player.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this Player.


        :param height: The height of this Player.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def weight(self):
        """Gets the weight of this Player.  # noqa: E501


        :return: The weight of this Player.  # noqa: E501
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this Player.


        :param weight: The weight of this Player.  # noqa: E501
        :type: int
        """

        self._weight = weight

    @property
    def jersey(self):
        """Gets the jersey of this Player.  # noqa: E501


        :return: The jersey of this Player.  # noqa: E501
        :rtype: int
        """
        return self._jersey

    @jersey.setter
    def jersey(self, jersey):
        """Sets the jersey of this Player.


        :param jersey: The jersey of this Player.  # noqa: E501
        :type: int
        """

        self._jersey = jersey

    @property
    def year(self):
        """Gets the year of this Player.  # noqa: E501


        :return: The year of this Player.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this Player.


        :param year: The year of this Player.  # noqa: E501
        :type: int
        """

        self._year = year

    @property
    def position(self):
        """Gets the position of this Player.  # noqa: E501


        :return: The position of this Player.  # noqa: E501
        :rtype: str
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this Player.


        :param position: The position of this Player.  # noqa: E501
        :type: str
        """

        self._position = position

    @property
    def city(self):
        """Gets the city of this Player.  # noqa: E501


        :return: The city of this Player.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this Player.


        :param city: The city of this Player.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this Player.  # noqa: E501


        :return: The state of this Player.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Player.


        :param state: The state of this Player.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this Player.  # noqa: E501


        :return: The country of this Player.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Player.


        :param country: The country of this Player.  # noqa: E501
        :type: str
        """

        self._country = country

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Player, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Player):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Recruit(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recruit_type': 'str',
        'year': 'int',
        'ranking': 'int',
        'name': 'str',
        'school': 'str',
        'committed_to': 'str',
        'position': 'str',
        'height': 'int',
        'weight': 'int',
        'stars': 'int',
        'rating': 'float',
        'city': 'str',
        'state_province': 'str',
        'country': 'str'
    }

    attribute_map = {
        'recruit_type': 'recruitType',
        'year': 'year',
        'ranking': 'ranking',
        'name': 'name',
        'school': 'school',
        'committed_to': 'committedTo',
        'position': 'position',
        'height': 'height',
        'weight': 'weight',
        'stars': 'stars',
        'rating': 'rating',
        'city': 'city',
        'state_province': 'stateProvince',
        'country': 'country'
    }

    def __init__(self, recruit_type=None, year=None, ranking=None, name=None, school=None, committed_to=None, position=None, height=None, weight=None, stars=None, rating=None, city=None, state_province=None, country=None):  # noqa: E501
        """Recruit - a model defined in Swagger"""  # noqa: E501

        self._recruit_type = None
        self._year = None
        self._ranking = None
        self._name = None
        self._school = None
        self._committed_to = None
        self._position = None
        self._height = None
        self._weight = None
        self._stars = None
        self._rating = None
        self._city = None
        self._state_province = None
        self._country = None
        self.discriminator = None

        if recruit_type is not None:
            self.recruit_type = recruit_type
        if year is not None:
            self.year = year
        if ranking is not None:
            self.ranking = ranking
        if name is not None:
            self.name = name
        if school is not None:
            self.school = school
        if committed_to is not None:
            self.committed_to = committed_to
        if position is not None:
            self.position = position
        if height is not None:
            self.height = height
        if weight is not None:
            self.weight = weight
        if stars is not None:
            self.stars = stars
        if rating is not None:
            self.rating = rating
        if city is not None:
            self.city = city
        if state_province is not None:
            self.state_province = state_province
        if country is not None:
            self.country = country

    @property
    def recruit_type(self):
        """Gets the recruit_type of this Recruit.  # noqa: E501


        :return: The recruit_type of this Recruit.  # noqa: E501
        :rtype: str
        """
        return self._recruit_type

    @recruit_type.setter
    def recruit_type(self, recruit_type):
        """Sets the recruit_type of this Recruit.


        :param recruit_type: The recruit_type of this Recruit.  # noqa: E501
        :type: str
        """

        self._recruit_type = recruit_type

    @property
    def year(self):
        """Gets the year of this Recruit.  # noqa: E501


        :return: The year of this Recruit.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this Recruit.


        :param year: The year of this Recruit.  # noqa: E501
        :type: int
        """

        self._year = year

    @property
    def ranking(self):
        """Gets the ranking of this Recruit.  # noqa: E501


        :return: The ranking of this Recruit.  # noqa: E501
        :rtype: int
        """
        return self._ranking

    @ranking.setter
    def ranking(self, ranking):
        """Sets the ranking of this Recruit.


        :param ranking: The ranking of this Recruit.  # noqa: E501
        :type: int
        """

        self._ranking = ranking

    @property
    def name(self):
        """Gets the name of this Recruit.  # noqa: E501


        :return: The name of this Recruit.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Recruit.


        :param name: The name of this Recruit.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def school(self):
        """Gets the school of this Recruit.  # noqa: E501


        :return: The school of this Recruit.  # noqa: E501
        :rtype: str
        """
        return self._school

    @school.setter
    def school(self, school):
        """Sets the school of this Recruit.


        :param school: The school of this Recruit.  # noqa: E501
        :type: str
        """

        self._school = school

    @property
    def committed_to(self):
        """Gets the committed_to of this Recruit.  # noqa: E501


        :return: The committed_to of this Recruit.  # noqa: E501
        :rtype: str
        """
        return self._committed_to

    @committed_to.setter
    def committed_to(self, committed_to):
        """Sets the committed_to of this Recruit.


        :param committed_to: The committed_to of this Recruit.  # noqa: E501
        :type: str
        """

        self._committed_to = committed_to

    @property
    def position(self):
        """Gets the position of this Recruit.  # noqa: E501


        :return: The position of this Recruit.  # noqa: E501
        :rtype: str
        """
        return self._position

    @position.setter
    def position(self, position):
        """Sets the position of this Recruit.


        :param position: The position of this Recruit.  # noqa: E501
        :type: str
        """

        self._position = position

    @property
    def height(self):
        """Gets the height of this Recruit.  # noqa: E501


        :return: The height of this Recruit.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this Recruit.


        :param height: The height of this Recruit.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def weight(self):
        """Gets the weight of this Recruit.  # noqa: E501


        :return: The weight of this Recruit.  # noqa: E501
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """Sets the weight of this Recruit.


        :param weight: The weight of this Recruit.  # noqa: E501
        :type: int
        """

        self._weight = weight

    @property
    def stars(self):
        """Gets the stars of this Recruit.  # noqa: E501


        :return: The stars of this Recruit.  # noqa: E501
        :rtype: int
        """
        return self._stars

    @stars.setter
    def stars(self, stars):
        """Sets the stars of this Recruit.


        :param stars: The stars of this Recruit.  # noqa: E501
        :type: int
        """

        self._stars = stars

    @property
    def rating(self):
        """Gets the rating of this Recruit.  # noqa: E501


        :return: The rating of this Recruit.  # noqa: E501
        :rtype: float
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this Recruit.


        :param rating: The rating of this Recruit.  # noqa: E501
        :type: float
        """

        self._rating = rating

    @property
    def city(self):
        """Gets the city of this Recruit.  # noqa: E501


        :return: The city of this Recruit.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this Recruit.


        :param city: The city of this Recruit.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state_province(self):
        """Gets the state_province of this Recruit.  # noqa: E501


        :return: The state_province of this Recruit.  # noqa: E501
        :rtype: str
        """
        return self._state_province

    @state_province.setter
    def state_province(self, state_province):
        """Sets the state_province of this Recruit.


        :param state_province: The state_province of this Recruit.  # noqa: E501
        :type: str
        """

        self._state_province = state_province

    @property
    def country(self):
        """Gets the country of this Recruit.  # noqa: E501


        :return: The country of this Recruit.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this Recruit.


        :param country: The country of this Recruit.  # noqa: E501
        :type: str
        """

        self._country = country

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Recruit, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Recruit):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PlayWP(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'games_id': 'int',
        'play_id': 'int',
        'play_text': 'str',
        'home_id': 'int',
        'home': 'str',
        'away_id': 'int',
        'away': 'str',
        'spread': 'float',
        'home_ball': 'bool',
        'home_score': 'int',
        'away_score': 'int',
        'time_remaining': 'int',
        'yard_line': 'int',
        'down': 'int',
        'distance': 'int',
        'home_win_prob': 'float',
        'play_number': 'int'
    }

    attribute_map = {
        'games_id': 'gamesId',
        'play_id': 'playId',
        'play_text': 'playText',
        'home_id': 'homeId',
        'home': 'home',
        'away_id': 'awayId',
        'away': 'away',
        'spread': 'spread',
        'home_ball': 'homeBall',
        'home_score': 'homeScore',
        'away_score': 'awayScore',
        'time_remaining': 'timeRemaining',
        'yard_line': 'yardLine',
        'down': 'down',
        'distance': 'distance',
        'home_win_prob': 'homeWinProb',
        'play_number': 'playNumber'
    }

    def __init__(self, games_id=None, play_id=None, play_text=None, home_id=None, home=None, away_id=None, away=None, spread=None, home_ball=None, home_score=None, away_score=None, time_remaining=None, yard_line=None, down=None, distance=None, home_win_prob=None, play_number=None):  # noqa: E501
        """PlayWP - a model defined in Swagger"""  # noqa: E501

        self._games_id = None
        self._play_id = None
        self._play_text = None
        self._home_id = None
        self._home = None
        self._away_id = None
        self._away = None
        self._spread = None
        self._home_ball = None
        self._home_score = None
        self._away_score = None
        self._time_remaining = None
        self._yard_line = None
        self._down = None
        self._distance = None
        self._home_win_prob = None
        self._play_number = None
        self.discriminator = None

        if games_id is not None:
            self.games_id = games_id
        if play_id is not None:
            self.play_id = play_id
        if play_text is not None:
            self.play_text = play_text
        if home_id is not None:
            self.home_id = home_id
        if home is not None:
            self.home = home
        if away_id is not None:
            self.away_id = away_id
        if away is not None:
            self.away = away
        if spread is not None:
            self.spread = spread
        if home_ball is not None:
            self.home_ball = home_ball
        if home_score is not None:
            self.home_score = home_score
        if away_score is not None:
            self.away_score = away_score
        if time_remaining is not None:
            self.time_remaining = time_remaining
        if yard_line is not None:
            self.yard_line = yard_line
        if down is not None:
            self.down = down
        if distance is not None:
            self.distance = distance
        if home_win_prob is not None:
            self.home_win_prob = home_win_prob
        if play_number is not None:
            self.play_number = play_number

    @property
    def games_id(self):
        """Gets the games_id of this PlayWP.  # noqa: E501


        :return: The games_id of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._games_id

    @games_id.setter
    def games_id(self, games_id):
        """Sets the games_id of this PlayWP.


        :param games_id: The games_id of this PlayWP.  # noqa: E501
        :type: int
        """

        self._games_id = games_id

    @property
    def play_id(self):
        """Gets the play_id of this PlayWP.  # noqa: E501


        :return: The play_id of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._play_id

    @play_id.setter
    def play_id(self, play_id):
        """Sets the play_id of this PlayWP.


        :param play_id: The play_id of this PlayWP.  # noqa: E501
        :type: int
        """

        self._play_id = play_id

    @property
    def play_text(self):
        """Gets the play_text of this PlayWP.  # noqa: E501


        :return: The play_text of this PlayWP.  # noqa: E501
        :rtype: str
        """
        return self._play_text

    @play_text.setter
    def play_text(self, play_text):
        """Sets the play_text of this PlayWP.


        :param play_text: The play_text of this PlayWP.  # noqa: E501
        :type: str
        """

        self._play_text = play_text

    @property
    def home_id(self):
        """Gets the home_id of this PlayWP.  # noqa: E501


        :return: The home_id of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._home_id

    @home_id.setter
    def home_id(self, home_id):
        """Sets the home_id of this PlayWP.


        :param home_id: The home_id of this PlayWP.  # noqa: E501
        :type: int
        """

        self._home_id = home_id

    @property
    def home(self):
        """Gets the home of this PlayWP.  # noqa: E501


        :return: The home of this PlayWP.  # noqa: E501
        :rtype: str
        """
        return self._home

    @home.setter
    def home(self, home):
        """Sets the home of this PlayWP.


        :param home: The home of this PlayWP.  # noqa: E501
        :type: str
        """

        self._home = home

    @property
    def away_id(self):
        """Gets the away_id of this PlayWP.  # noqa: E501


        :return: The away_id of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._away_id

    @away_id.setter
    def away_id(self, away_id):
        """Sets the away_id of this PlayWP.


        :param away_id: The away_id of this PlayWP.  # noqa: E501
        :type: int
        """

        self._away_id = away_id

    @property
    def away(self):
        """Gets the away of this PlayWP.  # noqa: E501


        :return: The away of this PlayWP.  # noqa: E501
        :rtype: str
        """
        return self._away

    @away.setter
    def away(self, away):
        """Sets the away of this PlayWP.


        :param away: The away of this PlayWP.  # noqa: E501
        :type: str
        """

        self._away = away

    @property
    def spread(self):
        """Gets the spread of this PlayWP.  # noqa: E501


        :return: The spread of this PlayWP.  # noqa: E501
        :rtype: float
        """
        return self._spread

    @spread.setter
    def spread(self, spread):
        """Sets the spread of this PlayWP.


        :param spread: The spread of this PlayWP.  # noqa: E501
        :type: float
        """

        self._spread = spread

    @property
    def home_ball(self):
        """Gets the home_ball of this PlayWP.  # noqa: E501


        :return: The home_ball of this PlayWP.  # noqa: E501
        :rtype: bool
        """
        return self._home_ball

    @home_ball.setter
    def home_ball(self, home_ball):
        """Sets the home_ball of this PlayWP.


        :param home_ball: The home_ball of this PlayWP.  # noqa: E501
        :type: bool
        """

        self._home_ball = home_ball

    @property
    def home_score(self):
        """Gets the home_score of this PlayWP.  # noqa: E501


        :return: The home_score of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._home_score

    @home_score.setter
    def home_score(self, home_score):
        """Sets the home_score of this PlayWP.


        :param home_score: The home_score of this PlayWP.  # noqa: E501
        :type: int
        """

        self._home_score = home_score

    @property
    def away_score(self):
        """Gets the away_score of this PlayWP.  # noqa: E501


        :return: The away_score of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._away_score

    @away_score.setter
    def away_score(self, away_score):
        """Sets the away_score of this PlayWP.


        :param away_score: The away_score of this PlayWP.  # noqa: E501
        :type: int
        """

        self._away_score = away_score

    @property
    def time_remaining(self):
        """Gets the time_remaining of this PlayWP.  # noqa: E501


        :return: The time_remaining of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._time_remaining

    @time_remaining.setter
    def time_remaining(self, time_remaining):
        """Sets the time_remaining of this PlayWP.


        :param time_remaining: The time_remaining of this PlayWP.  # noqa: E501
        :type: int
        """

        self._time_remaining = time_remaining

    @property
    def yard_line(self):
        """Gets the yard_line of this PlayWP.  # noqa: E501


        :return: The yard_line of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._yard_line

    @yard_line.setter
    def yard_line(self, yard_line):
        """Sets the yard_line of this PlayWP.


        :param yard_line: The yard_line of this PlayWP.  # noqa: E501
        :type: int
        """

        self._yard_line = yard_line

    @property
    def down(self):
        """Gets the down of this PlayWP.  # noqa: E501


        :return: The down of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._down

    @down.setter
    def down(self, down):
        """Sets the down of this PlayWP.


        :param down: The down of this PlayWP.  # noqa: E501
        :type: int
        """

        self._down = down

    @property
    def distance(self):
        """Gets the distance of this PlayWP.  # noqa: E501


        :return: The distance of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this PlayWP.


        :param distance: The distance of this PlayWP.  # noqa: E501
        :type: int
        """

        self._distance = distance

    @property
    def home_win_prob(self):
        """Gets the home_win_prob of this PlayWP.  # noqa: E501


        :return: The home_win_prob of this PlayWP.  # noqa: E501
        :rtype: float
        """
        return self._home_win_prob

    @home_win_prob.setter
    def home_win_prob(self, home_win_prob):
        """Sets the home_win_prob of this PlayWP.


        :param home_win_prob: The home_win_prob of this PlayWP.  # noqa: E501
        :type: float
        """

        self._home_win_prob = home_win_prob

    @property
    def play_number(self):
        """Gets the play_number of this PlayWP.  # noqa: E501


        :return: The play_number of this PlayWP.  # noqa: E501
        :rtype: int
        """
        return self._play_number

    @play_number.setter
    def play_number(self, play_number):
        """Sets the play_number of this PlayWP.


        :param play_number: The play_number of this PlayWP.  # noqa: E501
        :type: int
        """

        self._play_number = play_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlayWP, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayWP):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cfbd.api_client import ApiClient


class MetricsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_game_ppa(self, year, **kwargs):  # noqa: E501
        """Team Predicated Points Added (PPA/EPA) by game  # noqa: E501

        Predicted Points Added (PPA) by game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_game_ppa(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter (required)
        :param int week: Week filter
        :param str team: Team filter
        :param str conference: Conference filter
        :param bool exclude_garbage_time: Filter to remove garbage time plays from calculations
        :return: list[GamePPA]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_game_ppa_with_http_info(year, **kwargs)  # noqa: E501
        else:
            (data) = self.get_game_ppa_with_http_info(year, **kwargs)  # noqa: E501
            return data

    def get_game_ppa_with_http_info(self, year, **kwargs):  # noqa: E501
        """Team Predicated Points Added (PPA/EPA) by game  # noqa: E501

        Predicted Points Added (PPA) by game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_game_ppa_with_http_info(year, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter (required)
        :param int week: Week filter
        :param str team: Team filter
        :param str conference: Conference filter
        :param bool exclude_garbage_time: Filter to remove garbage time plays from calculations
        :return: list[GamePPA]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'team', 'conference', 'exclude_garbage_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_game_ppa" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'year' is set
        if ('year' not in params or
                params['year'] is None):
            raise ValueError("Missing the required parameter `year` when calling `get_game_ppa`")  # noqa: E501

        if 'year' in params and params['year'] < 2001:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_game_ppa`, must be a value greater than or equal to `2001`")  # noqa: E501
        if 'week' in params and params['week'] > 16:  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_game_ppa`, must be a value less than or equal to `16`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'exclude_garbage_time' in params:
            query_params.append(('excludeGarbageTime', params['exclude_garbage_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ppa/games', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GamePPA]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_player_game_ppa(self, **kwargs):  # noqa: E501
        """Player Predicated Points Added (PPA/EPA) broken down by game  # noqa: E501

        Predicted Points Added (PPA) by player game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_player_game_ppa(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :param int week: Week filter
        :param str team: Team filter
        :param str position: Position abbreviation filter
        :param int player_id: Player id filter
        :param str threshold: Minimum play threshold filter
        :param bool exclude_garbage_time: Filter to remove garbage time plays from calculations
        :return: list[PlayerGamePPA]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_player_game_ppa_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_player_game_ppa_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_player_game_ppa_with_http_info(self, **kwargs):  # noqa: E501
        """Player Predicated Points Added (PPA/EPA) broken down by game  # noqa: E501

        Predicted Points Added (PPA) by player game  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_player_game_ppa_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :param int week: Week filter
        :param str team: Team filter
        :param str position: Position abbreviation filter
        :param int player_id: Player id filter
        :param str threshold: Minimum play threshold filter
        :param bool exclude_garbage_time: Filter to remove garbage time plays from calculations
        :return: list[PlayerGamePPA]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'team', 'position', 'player_id', 'threshold', 'exclude_garbage_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_player_game_ppa" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 2013:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_player_game_ppa`, must be a value greater than or equal to `2013`")  # noqa: E501
        if 'week' in params and params['week'] > 16:  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_player_game_ppa`, must be a value less than or equal to `16`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'position' in params:
            query_params.append(('position', params['position']))  # noqa: E501
        if 'player_id' in params:
            query_params.append(('playerId', params['player_id']))  # noqa: E501
        if 'threshold' in params:
            query_params.append(('threshold', params['threshold']))  # noqa: E501
        if 'exclude_garbage_time' in params:
            query_params.append(('excludeGarbageTime', params['exclude_garbage_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ppa/players/games', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PlayerGamePPA]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_player_season_ppa(self, **kwargs):  # noqa: E501
        """Player Predicated Points Added (PPA/EPA) broken down by season  # noqa: E501

        Predicted Points Added (PPA) by player season  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_player_season_ppa(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :param str team: Team filter
        :param str conference: Conference abbreviation filter
        :param str position: Position abbreviation filter
        :param int player_id: Player id filter
        :param str threshold: Minimum play threshold filter
        :param bool exclude_garbage_time: Filter to remove garbage time plays from calculations
        :return: list[PlayerSeasonPPA]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_player_season_ppa_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_player_season_ppa_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_player_season_ppa_with_http_info(self, **kwargs):  # noqa: E501
        """Player Predicated Points Added (PPA/EPA) broken down by season  # noqa: E501

        Predicted Points Added (PPA) by player season  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_player_season_ppa_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :param str team: Team filter
        :param str conference: Conference abbreviation filter
        :param str position: Position abbreviation filter
        :param int player_id: Player id filter
        :param str threshold: Minimum play threshold filter
        :param bool exclude_garbage_time: Filter to remove garbage time plays from calculations
        :return: list[PlayerSeasonPPA]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'team', 'conference', 'position', 'player_id', 'threshold', 'exclude_garbage_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_player_season_ppa" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 2013:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_player_season_ppa`, must be a value greater than or equal to `2013`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'position' in params:
            query_params.append(('position', params['position']))  # noqa: E501
        if 'player_id' in params:
            query_params.append(('playerId', params['player_id']))  # noqa: E501
        if 'threshold' in params:
            query_params.append(('threshold', params['threshold']))  # noqa: E501
        if 'exclude_garbage_time' in params:
            query_params.append(('excludeGarbageTime', params['exclude_garbage_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ppa/players/season', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PlayerSeasonPPA]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_predicted_points(self, down, distance, **kwargs):  # noqa: E501
        """Predicted Points (i.e. Expected Points or EP)  # noqa: E501

        Predicted Points  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_predicted_points(down, distance, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int down: Down filter (required)
        :param int distance: Distance filter (required)
        :return: list[PredictedPoints]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_predicted_points_with_http_info(down, distance, **kwargs)  # noqa: E501
        else:
            (data) = self.get_predicted_points_with_http_info(down, distance, **kwargs)  # noqa: E501
            return data

    def get_predicted_points_with_http_info(self, down, distance, **kwargs):  # noqa: E501
        """Predicted Points (i.e. Expected Points or EP)  # noqa: E501

        Predicted Points  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_predicted_points_with_http_info(down, distance, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int down: Down filter (required)
        :param int distance: Distance filter (required)
        :return: list[PredictedPoints]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['down', 'distance']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_predicted_points" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'down' is set
        if ('down' not in params or
                params['down'] is None):
            raise ValueError("Missing the required parameter `down` when calling `get_predicted_points`")  # noqa: E501
        # verify the required parameter 'distance' is set
        if ('distance' not in params or
                params['distance'] is None):
            raise ValueError("Missing the required parameter `distance` when calling `get_predicted_points`")  # noqa: E501

        if 'down' in params and params['down'] > 4:  # noqa: E501
            raise ValueError("Invalid value for parameter `down` when calling `get_predicted_points`, must be a value less than or equal to `4`")  # noqa: E501
        if 'down' in params and params['down'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `down` when calling `get_predicted_points`, must be a value greater than or equal to `1`")  # noqa: E501
        if 'distance' in params and params['distance'] > 99:  # noqa: E501
            raise ValueError("Invalid value for parameter `distance` when calling `get_predicted_points`, must be a value less than or equal to `99`")  # noqa: E501
        if 'distance' in params and params['distance'] < 1:  # noqa: E501
            raise ValueError("Invalid value for parameter `distance` when calling `get_predicted_points`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'down' in params:
            query_params.append(('down', params['down']))  # noqa: E501
        if 'distance' in params:
            query_params.append(('distance', params['distance']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ppa/predicted', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PredictedPoints]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pregame_win_probabilities(self, **kwargs):  # noqa: E501
        """Pregame win probability data  # noqa: E501

        Pregame win probabilities  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pregame_win_probabilities(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :param int week: Week filter
        :param str team: Team filter
        :param str season_type: regular or postseason
        :return: list[PregameWP]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_pregame_win_probabilities_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_pregame_win_probabilities_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_pregame_win_probabilities_with_http_info(self, **kwargs):  # noqa: E501
        """Pregame win probability data  # noqa: E501

        Pregame win probabilities  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pregame_win_probabilities_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter
        :param int week: Week filter
        :param str team: Team filter
        :param str season_type: regular or postseason
        :return: list[PregameWP]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'week', 'team', 'season_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pregame_win_probabilities" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 2001:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_pregame_win_probabilities`, must be a value greater than or equal to `2001`")  # noqa: E501
        if 'week' in params and params['week'] > 16:  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_pregame_win_probabilities`, must be a value less than or equal to `16`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'season_type' in params:
            query_params.append(('seasonType', params['season_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/metrics/wp/pregame', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PregameWP]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_team_ppa(self, **kwargs):  # noqa: E501
        """Predicted Points Added (PPA/EPA) data by team  # noqa: E501

        Predicted Points Added (PPA)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_ppa(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter (required if team not specified)
        :param str team: Team filter (required if year not specified)
        :param str conference: Conference filter
        :param bool exclude_garbage_time: Filter to remove garbage time plays from calculations
        :return: list[TeamPPA]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_team_ppa_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_team_ppa_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_team_ppa_with_http_info(self, **kwargs):  # noqa: E501
        """Predicted Points Added (PPA/EPA) data by team  # noqa: E501

        Predicted Points Added (PPA)  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_team_ppa_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int year: Year filter (required if team not specified)
        :param str team: Team filter (required if year not specified)
        :param str conference: Conference filter
        :param bool exclude_garbage_time: Filter to remove garbage time plays from calculations
        :return: list[TeamPPA]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['year', 'team', 'conference', 'exclude_garbage_time']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_team_ppa" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 2001:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_team_ppa`, must be a value greater than or equal to `2001`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501
        if 'exclude_garbage_time' in params:
            query_params.append(('excludeGarbageTime', params['exclude_garbage_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ppa/teams', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TeamPPA]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_win_probability_data(self, game_id, **kwargs):  # noqa: E501
        """Win probability chart data  # noqa: E501

        Win probability data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_win_probability_data(game_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int game_id: Game id filter (required)
        :return: list[PlayWP]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_win_probability_data_with_http_info(game_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_win_probability_data_with_http_info(game_id, **kwargs)  # noqa: E501
            return data

    def get_win_probability_data_with_http_info(self, game_id, **kwargs):  # noqa: E501
        """Win probability chart data  # noqa: E501

        Win probability data  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_win_probability_data_with_http_info(game_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int game_id: Game id filter (required)
        :return: list[PlayWP]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['game_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_win_probability_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'game_id' is set
        if ('game_id' not in params or
                params['game_id'] is None):
            raise ValueError("Missing the required parameter `game_id` when calling `get_win_probability_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'game_id' in params:
            query_params.append(('gameId', params['game_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/metrics/wp', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PlayWP]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PlayStat(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'game_id': 'int',
        'season': 'int',
        'week': 'int',
        'opponent': 'str',
        'team_score': 'int',
        'opponent_score': 'int',
        'drive_id': 'int',
        'play_id': 'int',
        'period': 'int',
        'clock': 'DriveStartTime',
        'yards_to_goal': 'int',
        'down': 'int',
        'distance': 'int',
        'athlete_id': 'int',
        'athlete_name': 'str',
        'stat_type': 'str',
        'stat': 'int'
    }

    attribute_map = {
        'game_id': 'gameId',
        'season': 'season',
        'week': 'week',
        'opponent': 'opponent',
        'team_score': 'teamScore',
        'opponent_score': 'opponentScore',
        'drive_id': 'driveId',
        'play_id': 'playId',
        'period': 'period',
        'clock': 'clock',
        'yards_to_goal': 'yardsToGoal',
        'down': 'down',
        'distance': 'distance',
        'athlete_id': 'athleteId',
        'athlete_name': 'athleteName',
        'stat_type': 'statType',
        'stat': 'stat'
    }

    def __init__(self, game_id=None, season=None, week=None, opponent=None, team_score=None, opponent_score=None, drive_id=None, play_id=None, period=None, clock=None, yards_to_goal=None, down=None, distance=None, athlete_id=None, athlete_name=None, stat_type=None, stat=None):  # noqa: E501
        """PlayStat - a model defined in Swagger"""  # noqa: E501

        self._game_id = None
        self._season = None
        self._week = None
        self._opponent = None
        self._team_score = None
        self._opponent_score = None
        self._drive_id = None
        self._play_id = None
        self._period = None
        self._clock = None
        self._yards_to_goal = None
        self._down = None
        self._distance = None
        self._athlete_id = None
        self._athlete_name = None
        self._stat_type = None
        self._stat = None
        self.discriminator = None

        if game_id is not None:
            self.game_id = game_id
        if season is not None:
            self.season = season
        if week is not None:
            self.week = week
        if opponent is not None:
            self.opponent = opponent
        if team_score is not None:
            self.team_score = team_score
        if opponent_score is not None:
            self.opponent_score = opponent_score
        if drive_id is not None:
            self.drive_id = drive_id
        if play_id is not None:
            self.play_id = play_id
        if period is not None:
            self.period = period
        if clock is not None:
            self.clock = clock
        if yards_to_goal is not None:
            self.yards_to_goal = yards_to_goal
        if down is not None:
            self.down = down
        if distance is not None:
            self.distance = distance
        if athlete_id is not None:
            self.athlete_id = athlete_id
        if athlete_name is not None:
            self.athlete_name = athlete_name
        if stat_type is not None:
            self.stat_type = stat_type
        if stat is not None:
            self.stat = stat

    @property
    def game_id(self):
        """Gets the game_id of this PlayStat.  # noqa: E501


        :return: The game_id of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._game_id

    @game_id.setter
    def game_id(self, game_id):
        """Sets the game_id of this PlayStat.


        :param game_id: The game_id of this PlayStat.  # noqa: E501
        :type: int
        """

        self._game_id = game_id

    @property
    def season(self):
        """Gets the season of this PlayStat.  # noqa: E501


        :return: The season of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._season

    @season.setter
    def season(self, season):
        """Sets the season of this PlayStat.


        :param season: The season of this PlayStat.  # noqa: E501
        :type: int
        """

        self._season = season

    @property
    def week(self):
        """Gets the week of this PlayStat.  # noqa: E501


        :return: The week of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._week

    @week.setter
    def week(self, week):
        """Sets the week of this PlayStat.


        :param week: The week of this PlayStat.  # noqa: E501
        :type: int
        """

        self._week = week

    @property
    def opponent(self):
        """Gets the opponent of this PlayStat.  # noqa: E501


        :return: The opponent of this PlayStat.  # noqa: E501
        :rtype: str
        """
        return self._opponent

    @opponent.setter
    def opponent(self, opponent):
        """Sets the opponent of this PlayStat.


        :param opponent: The opponent of this PlayStat.  # noqa: E501
        :type: str
        """

        self._opponent = opponent

    @property
    def team_score(self):
        """Gets the team_score of this PlayStat.  # noqa: E501


        :return: The team_score of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._team_score

    @team_score.setter
    def team_score(self, team_score):
        """Sets the team_score of this PlayStat.


        :param team_score: The team_score of this PlayStat.  # noqa: E501
        :type: int
        """

        self._team_score = team_score

    @property
    def opponent_score(self):
        """Gets the opponent_score of this PlayStat.  # noqa: E501


        :return: The opponent_score of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._opponent_score

    @opponent_score.setter
    def opponent_score(self, opponent_score):
        """Sets the opponent_score of this PlayStat.


        :param opponent_score: The opponent_score of this PlayStat.  # noqa: E501
        :type: int
        """

        self._opponent_score = opponent_score

    @property
    def drive_id(self):
        """Gets the drive_id of this PlayStat.  # noqa: E501


        :return: The drive_id of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._drive_id

    @drive_id.setter
    def drive_id(self, drive_id):
        """Sets the drive_id of this PlayStat.


        :param drive_id: The drive_id of this PlayStat.  # noqa: E501
        :type: int
        """

        self._drive_id = drive_id

    @property
    def play_id(self):
        """Gets the play_id of this PlayStat.  # noqa: E501


        :return: The play_id of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._play_id

    @play_id.setter
    def play_id(self, play_id):
        """Sets the play_id of this PlayStat.


        :param play_id: The play_id of this PlayStat.  # noqa: E501
        :type: int
        """

        self._play_id = play_id

    @property
    def period(self):
        """Gets the period of this PlayStat.  # noqa: E501


        :return: The period of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this PlayStat.


        :param period: The period of this PlayStat.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def clock(self):
        """Gets the clock of this PlayStat.  # noqa: E501


        :return: The clock of this PlayStat.  # noqa: E501
        :rtype: DriveStartTime
        """
        return self._clock

    @clock.setter
    def clock(self, clock):
        """Sets the clock of this PlayStat.


        :param clock: The clock of this PlayStat.  # noqa: E501
        :type: DriveStartTime
        """

        self._clock = clock

    @property
    def yards_to_goal(self):
        """Gets the yards_to_goal of this PlayStat.  # noqa: E501


        :return: The yards_to_goal of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._yards_to_goal

    @yards_to_goal.setter
    def yards_to_goal(self, yards_to_goal):
        """Sets the yards_to_goal of this PlayStat.


        :param yards_to_goal: The yards_to_goal of this PlayStat.  # noqa: E501
        :type: int
        """

        self._yards_to_goal = yards_to_goal

    @property
    def down(self):
        """Gets the down of this PlayStat.  # noqa: E501


        :return: The down of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._down

    @down.setter
    def down(self, down):
        """Sets the down of this PlayStat.


        :param down: The down of this PlayStat.  # noqa: E501
        :type: int
        """

        self._down = down

    @property
    def distance(self):
        """Gets the distance of this PlayStat.  # noqa: E501


        :return: The distance of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._distance

    @distance.setter
    def distance(self, distance):
        """Sets the distance of this PlayStat.


        :param distance: The distance of this PlayStat.  # noqa: E501
        :type: int
        """

        self._distance = distance

    @property
    def athlete_id(self):
        """Gets the athlete_id of this PlayStat.  # noqa: E501


        :return: The athlete_id of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._athlete_id

    @athlete_id.setter
    def athlete_id(self, athlete_id):
        """Sets the athlete_id of this PlayStat.


        :param athlete_id: The athlete_id of this PlayStat.  # noqa: E501
        :type: int
        """

        self._athlete_id = athlete_id

    @property
    def athlete_name(self):
        """Gets the athlete_name of this PlayStat.  # noqa: E501


        :return: The athlete_name of this PlayStat.  # noqa: E501
        :rtype: str
        """
        return self._athlete_name

    @athlete_name.setter
    def athlete_name(self, athlete_name):
        """Sets the athlete_name of this PlayStat.


        :param athlete_name: The athlete_name of this PlayStat.  # noqa: E501
        :type: str
        """

        self._athlete_name = athlete_name

    @property
    def stat_type(self):
        """Gets the stat_type of this PlayStat.  # noqa: E501


        :return: The stat_type of this PlayStat.  # noqa: E501
        :rtype: str
        """
        return self._stat_type

    @stat_type.setter
    def stat_type(self, stat_type):
        """Sets the stat_type of this PlayStat.


        :param stat_type: The stat_type of this PlayStat.  # noqa: E501
        :type: str
        """

        self._stat_type = stat_type

    @property
    def stat(self):
        """Gets the stat of this PlayStat.  # noqa: E501


        :return: The stat of this PlayStat.  # noqa: E501
        :rtype: int
        """
        return self._stat

    @stat.setter
    def stat(self, stat):
        """Sets the stat of this PlayStat.


        :param stat: The stat of this PlayStat.  # noqa: E501
        :type: int
        """

        self._stat = stat

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlayStat, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayStat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class PlayerSeasonStat(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'season': 'int',
        'player_id': 'int',
        'player': 'str',
        'team': 'str',
        'conference': 'str',
        'category': 'str',
        'stat_type': 'str',
        'stat': 'float'
    }

    attribute_map = {
        'season': 'season',
        'player_id': 'playerId',
        'player': 'player',
        'team': 'team',
        'conference': 'conference',
        'category': 'category',
        'stat_type': 'statType',
        'stat': 'stat'
    }

    def __init__(self, season=None, player_id=None, player=None, team=None, conference=None, category=None, stat_type=None, stat=None):  # noqa: E501
        """PlayerSeasonStat - a model defined in Swagger"""  # noqa: E501

        self._season = None
        self._player_id = None
        self._player = None
        self._team = None
        self._conference = None
        self._category = None
        self._stat_type = None
        self._stat = None
        self.discriminator = None

        if season is not None:
            self.season = season
        if player_id is not None:
            self.player_id = player_id
        if player is not None:
            self.player = player
        if team is not None:
            self.team = team
        if conference is not None:
            self.conference = conference
        if category is not None:
            self.category = category
        if stat_type is not None:
            self.stat_type = stat_type
        if stat is not None:
            self.stat = stat

    @property
    def season(self):
        """Gets the season of this PlayerSeasonStat.  # noqa: E501


        :return: The season of this PlayerSeasonStat.  # noqa: E501
        :rtype: int
        """
        return self._season

    @season.setter
    def season(self, season):
        """Sets the season of this PlayerSeasonStat.


        :param season: The season of this PlayerSeasonStat.  # noqa: E501
        :type: int
        """

        self._season = season

    @property
    def player_id(self):
        """Gets the player_id of this PlayerSeasonStat.  # noqa: E501


        :return: The player_id of this PlayerSeasonStat.  # noqa: E501
        :rtype: int
        """
        return self._player_id

    @player_id.setter
    def player_id(self, player_id):
        """Sets the player_id of this PlayerSeasonStat.


        :param player_id: The player_id of this PlayerSeasonStat.  # noqa: E501
        :type: int
        """

        self._player_id = player_id

    @property
    def player(self):
        """Gets the player of this PlayerSeasonStat.  # noqa: E501


        :return: The player of this PlayerSeasonStat.  # noqa: E501
        :rtype: str
        """
        return self._player

    @player.setter
    def player(self, player):
        """Sets the player of this PlayerSeasonStat.


        :param player: The player of this PlayerSeasonStat.  # noqa: E501
        :type: str
        """

        self._player = player

    @property
    def team(self):
        """Gets the team of this PlayerSeasonStat.  # noqa: E501


        :return: The team of this PlayerSeasonStat.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this PlayerSeasonStat.


        :param team: The team of this PlayerSeasonStat.  # noqa: E501
        :type: str
        """

        self._team = team

    @property
    def conference(self):
        """Gets the conference of this PlayerSeasonStat.  # noqa: E501


        :return: The conference of this PlayerSeasonStat.  # noqa: E501
        :rtype: str
        """
        return self._conference

    @conference.setter
    def conference(self, conference):
        """Sets the conference of this PlayerSeasonStat.


        :param conference: The conference of this PlayerSeasonStat.  # noqa: E501
        :type: str
        """

        self._conference = conference

    @property
    def category(self):
        """Gets the category of this PlayerSeasonStat.  # noqa: E501


        :return: The category of this PlayerSeasonStat.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this PlayerSeasonStat.


        :param category: The category of this PlayerSeasonStat.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def stat_type(self):
        """Gets the stat_type of this PlayerSeasonStat.  # noqa: E501


        :return: The stat_type of this PlayerSeasonStat.  # noqa: E501
        :rtype: str
        """
        return self._stat_type

    @stat_type.setter
    def stat_type(self, stat_type):
        """Sets the stat_type of this PlayerSeasonStat.


        :param stat_type: The stat_type of this PlayerSeasonStat.  # noqa: E501
        :type: str
        """

        self._stat_type = stat_type

    @property
    def stat(self):
        """Gets the stat of this PlayerSeasonStat.  # noqa: E501


        :return: The stat of this PlayerSeasonStat.  # noqa: E501
        :rtype: float
        """
        return self._stat

    @stat.setter
    def stat(self, stat):
        """Sets the stat of this PlayerSeasonStat.


        :param stat: The stat of this PlayerSeasonStat.  # noqa: E501
        :type: float
        """

        self._stat = stat

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlayerSeasonStat, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayerSeasonStat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TeamSRSRating(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'year': 'int',
        'team': 'str',
        'conference': 'str',
        'division': 'str',
        'rating': 'float'
    }

    attribute_map = {
        'year': 'year',
        'team': 'team',
        'conference': 'conference',
        'division': 'division',
        'rating': 'rating'
    }

    def __init__(self, year=None, team=None, conference=None, division=None, rating=None):  # noqa: E501
        """TeamSRSRating - a model defined in Swagger"""  # noqa: E501

        self._year = None
        self._team = None
        self._conference = None
        self._division = None
        self._rating = None
        self.discriminator = None

        if year is not None:
            self.year = year
        if team is not None:
            self.team = team
        if conference is not None:
            self.conference = conference
        if division is not None:
            self.division = division
        if rating is not None:
            self.rating = rating

    @property
    def year(self):
        """Gets the year of this TeamSRSRating.  # noqa: E501


        :return: The year of this TeamSRSRating.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this TeamSRSRating.


        :param year: The year of this TeamSRSRating.  # noqa: E501
        :type: int
        """

        self._year = year

    @property
    def team(self):
        """Gets the team of this TeamSRSRating.  # noqa: E501


        :return: The team of this TeamSRSRating.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this TeamSRSRating.


        :param team: The team of this TeamSRSRating.  # noqa: E501
        :type: str
        """

        self._team = team

    @property
    def conference(self):
        """Gets the conference of this TeamSRSRating.  # noqa: E501


        :return: The conference of this TeamSRSRating.  # noqa: E501
        :rtype: str
        """
        return self._conference

    @conference.setter
    def conference(self, conference):
        """Sets the conference of this TeamSRSRating.


        :param conference: The conference of this TeamSRSRating.  # noqa: E501
        :type: str
        """

        self._conference = conference

    @property
    def division(self):
        """Gets the division of this TeamSRSRating.  # noqa: E501


        :return: The division of this TeamSRSRating.  # noqa: E501
        :rtype: str
        """
        return self._division

    @division.setter
    def division(self, division):
        """Sets the division of this TeamSRSRating.


        :param division: The division of this TeamSRSRating.  # noqa: E501
        :type: str
        """

        self._division = division

    @property
    def rating(self):
        """Gets the rating of this TeamSRSRating.  # noqa: E501


        :return: The rating of this TeamSRSRating.  # noqa: E501
        :rtype: float
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this TeamSRSRating.


        :param rating: The rating of this TeamSRSRating.  # noqa: E501
        :type: float
        """

        self._rating = rating

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TeamSRSRating, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamSRSRating):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TeamSPRatingDefense(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rating': 'float',
        'success': 'float',
        'explosiveness': 'float',
        'rushing': 'float',
        'pasing': 'float',
        'standard_downs': 'float',
        'passing_downs': 'float',
        'havoc': 'TeamSPRatingDefenseHavoc'
    }

    attribute_map = {
        'rating': 'rating',
        'success': 'success',
        'explosiveness': 'explosiveness',
        'rushing': 'rushing',
        'pasing': 'pasing',
        'standard_downs': 'standardDowns',
        'passing_downs': 'passingDowns',
        'havoc': 'havoc'
    }

    def __init__(self, rating=None, success=None, explosiveness=None, rushing=None, pasing=None, standard_downs=None, passing_downs=None, havoc=None):  # noqa: E501
        """TeamSPRatingDefense - a model defined in Swagger"""  # noqa: E501

        self._rating = None
        self._success = None
        self._explosiveness = None
        self._rushing = None
        self._pasing = None
        self._standard_downs = None
        self._passing_downs = None
        self._havoc = None
        self.discriminator = None

        if rating is not None:
            self.rating = rating
        if success is not None:
            self.success = success
        if explosiveness is not None:
            self.explosiveness = explosiveness
        if rushing is not None:
            self.rushing = rushing
        if pasing is not None:
            self.pasing = pasing
        if standard_downs is not None:
            self.standard_downs = standard_downs
        if passing_downs is not None:
            self.passing_downs = passing_downs
        if havoc is not None:
            self.havoc = havoc

    @property
    def rating(self):
        """Gets the rating of this TeamSPRatingDefense.  # noqa: E501


        :return: The rating of this TeamSPRatingDefense.  # noqa: E501
        :rtype: float
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this TeamSPRatingDefense.


        :param rating: The rating of this TeamSPRatingDefense.  # noqa: E501
        :type: float
        """

        self._rating = rating

    @property
    def success(self):
        """Gets the success of this TeamSPRatingDefense.  # noqa: E501


        :return: The success of this TeamSPRatingDefense.  # noqa: E501
        :rtype: float
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this TeamSPRatingDefense.


        :param success: The success of this TeamSPRatingDefense.  # noqa: E501
        :type: float
        """

        self._success = success

    @property
    def explosiveness(self):
        """Gets the explosiveness of this TeamSPRatingDefense.  # noqa: E501


        :return: The explosiveness of this TeamSPRatingDefense.  # noqa: E501
        :rtype: float
        """
        return self._explosiveness

    @explosiveness.setter
    def explosiveness(self, explosiveness):
        """Sets the explosiveness of this TeamSPRatingDefense.


        :param explosiveness: The explosiveness of this TeamSPRatingDefense.  # noqa: E501
        :type: float
        """

        self._explosiveness = explosiveness

    @property
    def rushing(self):
        """Gets the rushing of this TeamSPRatingDefense.  # noqa: E501


        :return: The rushing of this TeamSPRatingDefense.  # noqa: E501
        :rtype: float
        """
        return self._rushing

    @rushing.setter
    def rushing(self, rushing):
        """Sets the rushing of this TeamSPRatingDefense.


        :param rushing: The rushing of this TeamSPRatingDefense.  # noqa: E501
        :type: float
        """

        self._rushing = rushing

    @property
    def pasing(self):
        """Gets the pasing of this TeamSPRatingDefense.  # noqa: E501


        :return: The pasing of this TeamSPRatingDefense.  # noqa: E501
        :rtype: float
        """
        return self._pasing

    @pasing.setter
    def pasing(self, pasing):
        """Sets the pasing of this TeamSPRatingDefense.


        :param pasing: The pasing of this TeamSPRatingDefense.  # noqa: E501
        :type: float
        """

        self._pasing = pasing

    @property
    def standard_downs(self):
        """Gets the standard_downs of this TeamSPRatingDefense.  # noqa: E501


        :return: The standard_downs of this TeamSPRatingDefense.  # noqa: E501
        :rtype: float
        """
        return self._standard_downs

    @standard_downs.setter
    def standard_downs(self, standard_downs):
        """Sets the standard_downs of this TeamSPRatingDefense.


        :param standard_downs: The standard_downs of this TeamSPRatingDefense.  # noqa: E501
        :type: float
        """

        self._standard_downs = standard_downs

    @property
    def passing_downs(self):
        """Gets the passing_downs of this TeamSPRatingDefense.  # noqa: E501


        :return: The passing_downs of this TeamSPRatingDefense.  # noqa: E501
        :rtype: float
        """
        return self._passing_downs

    @passing_downs.setter
    def passing_downs(self, passing_downs):
        """Sets the passing_downs of this TeamSPRatingDefense.


        :param passing_downs: The passing_downs of this TeamSPRatingDefense.  # noqa: E501
        :type: float
        """

        self._passing_downs = passing_downs

    @property
    def havoc(self):
        """Gets the havoc of this TeamSPRatingDefense.  # noqa: E501


        :return: The havoc of this TeamSPRatingDefense.  # noqa: E501
        :rtype: TeamSPRatingDefenseHavoc
        """
        return self._havoc

    @havoc.setter
    def havoc(self, havoc):
        """Sets the havoc of this TeamSPRatingDefense.


        :param havoc: The havoc of this TeamSPRatingDefense.  # noqa: E501
        :type: TeamSPRatingDefenseHavoc
        """

        self._havoc = havoc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TeamSPRatingDefense, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamSPRatingDefense):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class TeamMatchupGames(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'season': 'int',
        'week': 'int',
        'season_type': 'str',
        '_date': 'str',
        'neutral_site': 'bool',
        'venue': 'str',
        'home_team': 'str',
        'home_score': 'int',
        'away_team': 'str',
        'away_score': 'int',
        'winner': 'str'
    }

    attribute_map = {
        'season': 'season',
        'week': 'week',
        'season_type': 'season_type',
        '_date': 'date',
        'neutral_site': 'neutralSite',
        'venue': 'venue',
        'home_team': 'homeTeam',
        'home_score': 'homeScore',
        'away_team': 'awayTeam',
        'away_score': 'awayScore',
        'winner': 'winner'
    }

    def __init__(self, season=None, week=None, season_type=None, _date=None, neutral_site=None, venue=None, home_team=None, home_score=None, away_team=None, away_score=None, winner=None):  # noqa: E501
        """TeamMatchupGames - a model defined in Swagger"""  # noqa: E501

        self._season = None
        self._week = None
        self._season_type = None
        self.__date = None
        self._neutral_site = None
        self._venue = None
        self._home_team = None
        self._home_score = None
        self._away_team = None
        self._away_score = None
        self._winner = None
        self.discriminator = None

        if season is not None:
            self.season = season
        if week is not None:
            self.week = week
        if season_type is not None:
            self.season_type = season_type
        if _date is not None:
            self._date = _date
        if neutral_site is not None:
            self.neutral_site = neutral_site
        if venue is not None:
            self.venue = venue
        if home_team is not None:
            self.home_team = home_team
        if home_score is not None:
            self.home_score = home_score
        if away_team is not None:
            self.away_team = away_team
        if away_score is not None:
            self.away_score = away_score
        if winner is not None:
            self.winner = winner

    @property
    def season(self):
        """Gets the season of this TeamMatchupGames.  # noqa: E501


        :return: The season of this TeamMatchupGames.  # noqa: E501
        :rtype: int
        """
        return self._season

    @season.setter
    def season(self, season):
        """Sets the season of this TeamMatchupGames.


        :param season: The season of this TeamMatchupGames.  # noqa: E501
        :type: int
        """

        self._season = season

    @property
    def week(self):
        """Gets the week of this TeamMatchupGames.  # noqa: E501


        :return: The week of this TeamMatchupGames.  # noqa: E501
        :rtype: int
        """
        return self._week

    @week.setter
    def week(self, week):
        """Sets the week of this TeamMatchupGames.


        :param week: The week of this TeamMatchupGames.  # noqa: E501
        :type: int
        """

        self._week = week

    @property
    def season_type(self):
        """Gets the season_type of this TeamMatchupGames.  # noqa: E501


        :return: The season_type of this TeamMatchupGames.  # noqa: E501
        :rtype: str
        """
        return self._season_type

    @season_type.setter
    def season_type(self, season_type):
        """Sets the season_type of this TeamMatchupGames.


        :param season_type: The season_type of this TeamMatchupGames.  # noqa: E501
        :type: str
        """

        self._season_type = season_type

    @property
    def _date(self):
        """Gets the _date of this TeamMatchupGames.  # noqa: E501


        :return: The _date of this TeamMatchupGames.  # noqa: E501
        :rtype: str
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this TeamMatchupGames.


        :param _date: The _date of this TeamMatchupGames.  # noqa: E501
        :type: str
        """

        self.__date = _date

    @property
    def neutral_site(self):
        """Gets the neutral_site of this TeamMatchupGames.  # noqa: E501


        :return: The neutral_site of this TeamMatchupGames.  # noqa: E501
        :rtype: bool
        """
        return self._neutral_site

    @neutral_site.setter
    def neutral_site(self, neutral_site):
        """Sets the neutral_site of this TeamMatchupGames.


        :param neutral_site: The neutral_site of this TeamMatchupGames.  # noqa: E501
        :type: bool
        """

        self._neutral_site = neutral_site

    @property
    def venue(self):
        """Gets the venue of this TeamMatchupGames.  # noqa: E501


        :return: The venue of this TeamMatchupGames.  # noqa: E501
        :rtype: str
        """
        return self._venue

    @venue.setter
    def venue(self, venue):
        """Sets the venue of this TeamMatchupGames.


        :param venue: The venue of this TeamMatchupGames.  # noqa: E501
        :type: str
        """

        self._venue = venue

    @property
    def home_team(self):
        """Gets the home_team of this TeamMatchupGames.  # noqa: E501


        :return: The home_team of this TeamMatchupGames.  # noqa: E501
        :rtype: str
        """
        return self._home_team

    @home_team.setter
    def home_team(self, home_team):
        """Sets the home_team of this TeamMatchupGames.


        :param home_team: The home_team of this TeamMatchupGames.  # noqa: E501
        :type: str
        """

        self._home_team = home_team

    @property
    def home_score(self):
        """Gets the home_score of this TeamMatchupGames.  # noqa: E501


        :return: The home_score of this TeamMatchupGames.  # noqa: E501
        :rtype: int
        """
        return self._home_score

    @home_score.setter
    def home_score(self, home_score):
        """Sets the home_score of this TeamMatchupGames.


        :param home_score: The home_score of this TeamMatchupGames.  # noqa: E501
        :type: int
        """

        self._home_score = home_score

    @property
    def away_team(self):
        """Gets the away_team of this TeamMatchupGames.  # noqa: E501


        :return: The away_team of this TeamMatchupGames.  # noqa: E501
        :rtype: str
        """
        return self._away_team

    @away_team.setter
    def away_team(self, away_team):
        """Sets the away_team of this TeamMatchupGames.


        :param away_team: The away_team of this TeamMatchupGames.  # noqa: E501
        :type: str
        """

        self._away_team = away_team

    @property
    def away_score(self):
        """Gets the away_score of this TeamMatchupGames.  # noqa: E501


        :return: The away_score of this TeamMatchupGames.  # noqa: E501
        :rtype: int
        """
        return self._away_score

    @away_score.setter
    def away_score(self, away_score):
        """Sets the away_score of this TeamMatchupGames.


        :param away_score: The away_score of this TeamMatchupGames.  # noqa: E501
        :type: int
        """

        self._away_score = away_score

    @property
    def winner(self):
        """Gets the winner of this TeamMatchupGames.  # noqa: E501


        :return: The winner of this TeamMatchupGames.  # noqa: E501
        :rtype: str
        """
        return self._winner

    @winner.setter
    def winner(self, winner):
        """Sets the winner of this TeamMatchupGames.


        :param winner: The winner of this TeamMatchupGames.  # noqa: E501
        :type: str
        """

        self._winner = winner

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TeamMatchupGames, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamMatchupGames):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cfbd.api_client import ApiClient


class BettingApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_lines(self, **kwargs):  # noqa: E501
        """Betting lines  # noqa: E501

        Closing betting lines  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_lines(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int game_id: Game id filter
        :param int year: Year/season filter for games
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team
        :param str home: Home team filter
        :param str away: Away team filter
        :param str conference: Conference abbreviation filter
        :return: list[GameLines]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_lines_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_lines_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_lines_with_http_info(self, **kwargs):  # noqa: E501
        """Betting lines  # noqa: E501

        Closing betting lines  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_lines_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int game_id: Game id filter
        :param int year: Year/season filter for games
        :param int week: Week filter
        :param str season_type: Season type filter (regular or postseason)
        :param str team: Team
        :param str home: Home team filter
        :param str away: Away team filter
        :param str conference: Conference abbreviation filter
        :return: list[GameLines]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['game_id', 'year', 'week', 'season_type', 'team', 'home', 'away', 'conference']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_lines" % key
                )
            params[key] = val
        del params['kwargs']

        if 'year' in params and params['year'] < 2013:  # noqa: E501
            raise ValueError("Invalid value for parameter `year` when calling `get_lines`, must be a value greater than or equal to `2013`")  # noqa: E501
        if 'week' in params and params['week'] > 16:  # noqa: E501
            raise ValueError("Invalid value for parameter `week` when calling `get_lines`, must be a value less than or equal to `16`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'game_id' in params:
            query_params.append(('gameId', params['game_id']))  # noqa: E501
        if 'year' in params:
            query_params.append(('year', params['year']))  # noqa: E501
        if 'week' in params:
            query_params.append(('week', params['week']))  # noqa: E501
        if 'season_type' in params:
            query_params.append(('seasonType', params['season_type']))  # noqa: E501
        if 'team' in params:
            query_params.append(('team', params['team']))  # noqa: E501
        if 'home' in params:
            query_params.append(('home', params['home']))  # noqa: E501
        if 'away' in params:
            query_params.append(('away', params['away']))  # noqa: E501
        if 'conference' in params:
            query_params.append(('conference', params['conference']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/lines', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GameLines]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class Drive(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'offense': 'str',
        'offense_conference': 'str',
        'defense': 'str',
        'defense_conference': 'str',
        'game_id': 'int',
        'id': 'int',
        'drive_number': 'int',
        'scoring': 'bool',
        'start_period': 'int',
        'start_yardline': 'int',
        'start_yards_to_goal': 'int',
        'start_time': 'DriveStartTime',
        'end_period': 'int',
        'end_yardline': 'int',
        'end_yards_to_goal': 'int',
        'end_time': 'DriveStartTime',
        'plays': 'int',
        'yards': 'int',
        'drive_result': 'str'
    }

    attribute_map = {
        'offense': 'offense',
        'offense_conference': 'offense_conference',
        'defense': 'defense',
        'defense_conference': 'defense_conference',
        'game_id': 'game_id',
        'id': 'id',
        'drive_number': 'drive_number',
        'scoring': 'scoring',
        'start_period': 'start_period',
        'start_yardline': 'start_yardline',
        'start_yards_to_goal': 'start_yards_to_goal',
        'start_time': 'start_time',
        'end_period': 'end_period',
        'end_yardline': 'end_yardline',
        'end_yards_to_goal': 'end_yards_to_goal',
        'end_time': 'end_time',
        'plays': 'plays',
        'yards': 'yards',
        'drive_result': 'drive_result'
    }

    def __init__(self, offense=None, offense_conference=None, defense=None, defense_conference=None, game_id=None, id=None, drive_number=None, scoring=None, start_period=None, start_yardline=None, start_yards_to_goal=None, start_time=None, end_period=None, end_yardline=None, end_yards_to_goal=None, end_time=None, plays=None, yards=None, drive_result=None):  # noqa: E501
        """Drive - a model defined in Swagger"""  # noqa: E501

        self._offense = None
        self._offense_conference = None
        self._defense = None
        self._defense_conference = None
        self._game_id = None
        self._id = None
        self._drive_number = None
        self._scoring = None
        self._start_period = None
        self._start_yardline = None
        self._start_yards_to_goal = None
        self._start_time = None
        self._end_period = None
        self._end_yardline = None
        self._end_yards_to_goal = None
        self._end_time = None
        self._plays = None
        self._yards = None
        self._drive_result = None
        self.discriminator = None

        if offense is not None:
            self.offense = offense
        if offense_conference is not None:
            self.offense_conference = offense_conference
        if defense is not None:
            self.defense = defense
        if defense_conference is not None:
            self.defense_conference = defense_conference
        if game_id is not None:
            self.game_id = game_id
        if id is not None:
            self.id = id
        if drive_number is not None:
            self.drive_number = drive_number
        if scoring is not None:
            self.scoring = scoring
        if start_period is not None:
            self.start_period = start_period
        if start_yardline is not None:
            self.start_yardline = start_yardline
        if start_yards_to_goal is not None:
            self.start_yards_to_goal = start_yards_to_goal
        if start_time is not None:
            self.start_time = start_time
        if end_period is not None:
            self.end_period = end_period
        if end_yardline is not None:
            self.end_yardline = end_yardline
        if end_yards_to_goal is not None:
            self.end_yards_to_goal = end_yards_to_goal
        if end_time is not None:
            self.end_time = end_time
        if plays is not None:
            self.plays = plays
        if yards is not None:
            self.yards = yards
        if drive_result is not None:
            self.drive_result = drive_result

    @property
    def offense(self):
        """Gets the offense of this Drive.  # noqa: E501


        :return: The offense of this Drive.  # noqa: E501
        :rtype: str
        """
        return self._offense

    @offense.setter
    def offense(self, offense):
        """Sets the offense of this Drive.


        :param offense: The offense of this Drive.  # noqa: E501
        :type: str
        """

        self._offense = offense

    @property
    def offense_conference(self):
        """Gets the offense_conference of this Drive.  # noqa: E501


        :return: The offense_conference of this Drive.  # noqa: E501
        :rtype: str
        """
        return self._offense_conference

    @offense_conference.setter
    def offense_conference(self, offense_conference):
        """Sets the offense_conference of this Drive.


        :param offense_conference: The offense_conference of this Drive.  # noqa: E501
        :type: str
        """

        self._offense_conference = offense_conference

    @property
    def defense(self):
        """Gets the defense of this Drive.  # noqa: E501


        :return: The defense of this Drive.  # noqa: E501
        :rtype: str
        """
        return self._defense

    @defense.setter
    def defense(self, defense):
        """Sets the defense of this Drive.


        :param defense: The defense of this Drive.  # noqa: E501
        :type: str
        """

        self._defense = defense

    @property
    def defense_conference(self):
        """Gets the defense_conference of this Drive.  # noqa: E501


        :return: The defense_conference of this Drive.  # noqa: E501
        :rtype: str
        """
        return self._defense_conference

    @defense_conference.setter
    def defense_conference(self, defense_conference):
        """Sets the defense_conference of this Drive.


        :param defense_conference: The defense_conference of this Drive.  # noqa: E501
        :type: str
        """

        self._defense_conference = defense_conference

    @property
    def game_id(self):
        """Gets the game_id of this Drive.  # noqa: E501


        :return: The game_id of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._game_id

    @game_id.setter
    def game_id(self, game_id):
        """Sets the game_id of this Drive.


        :param game_id: The game_id of this Drive.  # noqa: E501
        :type: int
        """

        self._game_id = game_id

    @property
    def id(self):
        """Gets the id of this Drive.  # noqa: E501


        :return: The id of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Drive.


        :param id: The id of this Drive.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def drive_number(self):
        """Gets the drive_number of this Drive.  # noqa: E501


        :return: The drive_number of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._drive_number

    @drive_number.setter
    def drive_number(self, drive_number):
        """Sets the drive_number of this Drive.


        :param drive_number: The drive_number of this Drive.  # noqa: E501
        :type: int
        """

        self._drive_number = drive_number

    @property
    def scoring(self):
        """Gets the scoring of this Drive.  # noqa: E501


        :return: The scoring of this Drive.  # noqa: E501
        :rtype: bool
        """
        return self._scoring

    @scoring.setter
    def scoring(self, scoring):
        """Sets the scoring of this Drive.


        :param scoring: The scoring of this Drive.  # noqa: E501
        :type: bool
        """

        self._scoring = scoring

    @property
    def start_period(self):
        """Gets the start_period of this Drive.  # noqa: E501


        :return: The start_period of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._start_period

    @start_period.setter
    def start_period(self, start_period):
        """Sets the start_period of this Drive.


        :param start_period: The start_period of this Drive.  # noqa: E501
        :type: int
        """

        self._start_period = start_period

    @property
    def start_yardline(self):
        """Gets the start_yardline of this Drive.  # noqa: E501


        :return: The start_yardline of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._start_yardline

    @start_yardline.setter
    def start_yardline(self, start_yardline):
        """Sets the start_yardline of this Drive.


        :param start_yardline: The start_yardline of this Drive.  # noqa: E501
        :type: int
        """

        self._start_yardline = start_yardline

    @property
    def start_yards_to_goal(self):
        """Gets the start_yards_to_goal of this Drive.  # noqa: E501


        :return: The start_yards_to_goal of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._start_yards_to_goal

    @start_yards_to_goal.setter
    def start_yards_to_goal(self, start_yards_to_goal):
        """Sets the start_yards_to_goal of this Drive.


        :param start_yards_to_goal: The start_yards_to_goal of this Drive.  # noqa: E501
        :type: int
        """

        self._start_yards_to_goal = start_yards_to_goal

    @property
    def start_time(self):
        """Gets the start_time of this Drive.  # noqa: E501


        :return: The start_time of this Drive.  # noqa: E501
        :rtype: DriveStartTime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this Drive.


        :param start_time: The start_time of this Drive.  # noqa: E501
        :type: DriveStartTime
        """

        self._start_time = start_time

    @property
    def end_period(self):
        """Gets the end_period of this Drive.  # noqa: E501


        :return: The end_period of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._end_period

    @end_period.setter
    def end_period(self, end_period):
        """Sets the end_period of this Drive.


        :param end_period: The end_period of this Drive.  # noqa: E501
        :type: int
        """

        self._end_period = end_period

    @property
    def end_yardline(self):
        """Gets the end_yardline of this Drive.  # noqa: E501


        :return: The end_yardline of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._end_yardline

    @end_yardline.setter
    def end_yardline(self, end_yardline):
        """Sets the end_yardline of this Drive.


        :param end_yardline: The end_yardline of this Drive.  # noqa: E501
        :type: int
        """

        self._end_yardline = end_yardline

    @property
    def end_yards_to_goal(self):
        """Gets the end_yards_to_goal of this Drive.  # noqa: E501


        :return: The end_yards_to_goal of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._end_yards_to_goal

    @end_yards_to_goal.setter
    def end_yards_to_goal(self, end_yards_to_goal):
        """Sets the end_yards_to_goal of this Drive.


        :param end_yards_to_goal: The end_yards_to_goal of this Drive.  # noqa: E501
        :type: int
        """

        self._end_yards_to_goal = end_yards_to_goal

    @property
    def end_time(self):
        """Gets the end_time of this Drive.  # noqa: E501


        :return: The end_time of this Drive.  # noqa: E501
        :rtype: DriveStartTime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this Drive.


        :param end_time: The end_time of this Drive.  # noqa: E501
        :type: DriveStartTime
        """

        self._end_time = end_time

    @property
    def plays(self):
        """Gets the plays of this Drive.  # noqa: E501


        :return: The plays of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._plays

    @plays.setter
    def plays(self, plays):
        """Sets the plays of this Drive.


        :param plays: The plays of this Drive.  # noqa: E501
        :type: int
        """

        self._plays = plays

    @property
    def yards(self):
        """Gets the yards of this Drive.  # noqa: E501


        :return: The yards of this Drive.  # noqa: E501
        :rtype: int
        """
        return self._yards

    @yards.setter
    def yards(self, yards):
        """Sets the yards of this Drive.


        :param yards: The yards of this Drive.  # noqa: E501
        :type: int
        """

        self._yards = yards

    @property
    def drive_result(self):
        """Gets the drive_result of this Drive.  # noqa: E501


        :return: The drive_result of this Drive.  # noqa: E501
        :rtype: str
        """
        return self._drive_result

    @drive_result.setter
    def drive_result(self, drive_result):
        """Sets the drive_result of this Drive.


        :param drive_result: The drive_result of this Drive.  # noqa: E501
        :type: str
        """

        self._drive_result = drive_result

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Drive, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Drive):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    College Football Data API

    This is an API for accessing all sorts of college football data.  It currently has a wide array of data ranging from play by play to player statistics to game scores and more.  # noqa: E501

    OpenAPI spec version: 2.2.9
    Contact: admin@collegefootballdata.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ConferenceSPRating(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'year': 'int',
        'conference': 'str',
        'rating': 'float',
        'second_order_wins': 'float',
        'sos': 'float',
        'offense': 'TeamSPRatingOffense',
        'defense': 'TeamSPRatingDefense',
        'special_teams': 'TeamSPRatingSpecialTeams'
    }

    attribute_map = {
        'year': 'year',
        'conference': 'conference',
        'rating': 'rating',
        'second_order_wins': 'secondOrderWins',
        'sos': 'sos',
        'offense': 'offense',
        'defense': 'defense',
        'special_teams': 'specialTeams'
    }

    def __init__(self, year=None, conference=None, rating=None, second_order_wins=None, sos=None, offense=None, defense=None, special_teams=None):  # noqa: E501
        """ConferenceSPRating - a model defined in Swagger"""  # noqa: E501

        self._year = None
        self._conference = None
        self._rating = None
        self._second_order_wins = None
        self._sos = None
        self._offense = None
        self._defense = None
        self._special_teams = None
        self.discriminator = None

        if year is not None:
            self.year = year
        if conference is not None:
            self.conference = conference
        if rating is not None:
            self.rating = rating
        if second_order_wins is not None:
            self.second_order_wins = second_order_wins
        if sos is not None:
            self.sos = sos
        if offense is not None:
            self.offense = offense
        if defense is not None:
            self.defense = defense
        if special_teams is not None:
            self.special_teams = special_teams

    @property
    def year(self):
        """Gets the year of this ConferenceSPRating.  # noqa: E501


        :return: The year of this ConferenceSPRating.  # noqa: E501
        :rtype: int
        """
        return self._year

    @year.setter
    def year(self, year):
        """Sets the year of this ConferenceSPRating.


        :param year: The year of this ConferenceSPRating.  # noqa: E501
        :type: int
        """

        self._year = year

    @property
    def conference(self):
        """Gets the conference of this ConferenceSPRating.  # noqa: E501


        :return: The conference of this ConferenceSPRating.  # noqa: E501
        :rtype: str
        """
        return self._conference

    @conference.setter
    def conference(self, conference):
        """Sets the conference of this ConferenceSPRating.


        :param conference: The conference of this ConferenceSPRating.  # noqa: E501
        :type: str
        """

        self._conference = conference

    @property
    def rating(self):
        """Gets the rating of this ConferenceSPRating.  # noqa: E501


        :return: The rating of this ConferenceSPRating.  # noqa: E501
        :rtype: float
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this ConferenceSPRating.


        :param rating: The rating of this ConferenceSPRating.  # noqa: E501
        :type: float
        """

        self._rating = rating

    @property
    def second_order_wins(self):
        """Gets the second_order_wins of this ConferenceSPRating.  # noqa: E501


        :return: The second_order_wins of this ConferenceSPRating.  # noqa: E501
        :rtype: float
        """
        return self._second_order_wins

    @second_order_wins.setter
    def second_order_wins(self, second_order_wins):
        """Sets the second_order_wins of this ConferenceSPRating.


        :param second_order_wins: The second_order_wins of this ConferenceSPRating.  # noqa: E501
        :type: float
        """

        self._second_order_wins = second_order_wins

    @property
    def sos(self):
        """Gets the sos of this ConferenceSPRating.  # noqa: E501


        :return: The sos of this ConferenceSPRating.  # noqa: E501
        :rtype: float
        """
        return self._sos

    @sos.setter
    def sos(self, sos):
        """Sets the sos of this ConferenceSPRating.


        :param sos: The sos of this ConferenceSPRating.  # noqa: E501
        :type: float
        """

        self._sos = sos

    @property
    def offense(self):
        """Gets the offense of this ConferenceSPRating.  # noqa: E501


        :return: The offense of this ConferenceSPRating.  # noqa: E501
        :rtype: TeamSPRatingOffense
        """
        return self._offense

    @offense.setter
    def offense(self, offense):
        """Sets the offense of this ConferenceSPRating.


        :param offense: The offense of this ConferenceSPRating.  # noqa: E501
        :type: TeamSPRatingOffense
        """

        self._offense = offense

    @property
    def defense(self):
        """Gets the defense of this ConferenceSPRating.  # noqa: E501


        :return: The defense of this ConferenceSPRating.  # noqa: E501
        :rtype: TeamSPRatingDefense
        """
        return self._defense

    @defense.setter
    def defense(self, defense):
        """Sets the defense of this ConferenceSPRating.


        :param defense: The defense of this ConferenceSPRating.  # noqa: E501
        :type: TeamSPRatingDefense
        """

        self._defense = defense

    @property
    def special_teams(self):
        """Gets the special_teams of this ConferenceSPRating.  # noqa: E501


        :return: The special_teams of this ConferenceSPRating.  # noqa: E501
        :rtype: TeamSPRatingSpecialTeams
        """
        return self._special_teams

    @special_teams.setter
    def special_teams(self, special_teams):
        """Sets the special_teams of this ConferenceSPRating.


        :param special_teams: The special_teams of this ConferenceSPRating.  # noqa: E501
        :type: TeamSPRatingSpecialTeams
        """

        self._special_teams = special_teams

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ConferenceSPRating, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConferenceSPRating):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
